@@ -482,7 +482,7 @@ show_cgroups_linux (void)
 
 		buf = b = strdup (buffer);
 		if (! buf)
-			die ("failed to alloate storage");
+			die ("failed to allocate storage");
 
 		hierarchy = strsep (&b, delim);
 		if (! hierarchy)
@@ -596,7 +596,12 @@ show_namespaces_linux (void)
 	DIR            *dir;
 	struct dirent  *ent;
 	char           *prefix_path = "/proc/self/ns";
-	char            path[MAXPATHLEN];
+
+	/* worst case, we will write to full paths to this buffer, plus a space
+	 * sparator and a terminator.
+	 */
+	char            path[(MAXPATHLEN*2) + 1 + 1];
+
 	char            link[MAXPATHLEN];
 	ssize_t         len;
 	PRList         *list = NULL;
@@ -624,7 +629,10 @@ show_namespaces_linux (void)
 		assert (len);
 		link[len] = '\0';
 
-		entry = pr_list_new (strdup (link));
+		memset (path, '\0', sizeof (path));
+		sprintf (path, "%s %s", ent->d_name, link);
+
+		entry = pr_list_new (strdup (path));
 		assert (entry);
 
 		assert (pr_list_prepend_str_sorted (list, entry));
@@ -641,18 +649,14 @@ show_namespaces_linux (void)
 
 		tmp = iter->data;
 
-		name = strsep (&tmp, ":");
+		name = strsep (&tmp, " ");
 		if (! name)
 			goto give_up;
 
-		value = strsep (&tmp, "]");
+		value = tmp;
 		if (! value)
 			goto give_up;
 
-		if (*value == '[' && *(value+1)) {
-			value++;
-		}
-
 		object_open (false);
 		entry (name, "%s", value);
 		object_close (false);
@@ -1146,11 +1150,11 @@ show_prctl_linux (void)
 	}
 #endif
 
-#ifdef PR_GET_UNALIGNED
+#ifdef PR_GET_UNALIGN
 	if (LINUX_KERNEL_MMR (2, 3, 48)) {
 		const char *value;
 
-		rc = prctl (PR_GET_UNALIGNED, &arg2, 0, 0, 0);
+		rc = prctl (PR_GET_UNALIGN, &arg2, 0, 0, 0);
 		if (rc < 0)
 			value = UNKNOWN_STR;
 		else {
@@ -1248,6 +1252,47 @@ show_prctl_linux (void)
 	else
 		entry ("clear child tid address", "%p", arg2);
 #endif
+
+#ifdef PR_GET_SPECULATION_CTRL
+	arg2 = PR_SPEC_STORE_BYPASS;
+	rc = prctl (PR_GET_SPECULATION_CTRL, arg2, 0, 0, 0);
+	if (rc < 0)
+		entry ("speculation", "%s", UNKNOWN_STR);
+	else
+		entry ("speculation", "0x%x", rc);
+#endif
+
+#ifdef PR_GET_TAGGED_ADDR_CTRL
+	rc = prctl (PR_GET_TAGGED_ADDR_CTRL, 0, 0, 0, 0);
+	if (rc < 0)
+		entry ("tagged address mode", "%s", UNKNOWN_STR);
+	else
+		entry ("tagged address mode", "%d", rc);
+#endif
+
+#ifdef PR_GET_FP_MODE
+	rc = prctl (PR_GET_FP_MODE, 0, 0, 0, 0);
+	if (rc < 0)
+		entry ("floating-point mode", "%s", UNKNOWN_STR);
+	else
+		entry ("floating-point mode", "0x%x", rc);
+#endif
+
+#ifdef PR_GET_IO_FLUSHER
+	rc = prctl (PR_GET_IO_FLUSHER, 0, 0, 0, 0);
+	if (rc < 0)
+		entry ("I/O flusher state", "%s", UNKNOWN_STR);
+	else
+		entry ("I/O flusher state", "%d", rc);
+#endif
+
+#ifdef PR_GET_THP_DISABLE
+	rc = prctl (PR_GET_THP_DISABLE, 0, 0, 0, 0);
+	if (rc < 0)
+		entry ("THP disable flag", "%s", UNKNOWN_STR);
+	else
+		entry ("THP disable flag", "%d", rc);
+#endif
 }
 
 static void
@@ -1888,7 +1933,7 @@ out:
  * has been specified as -1, subsequent parameters are ignored
  * (treated as -1 too).
  *
- * Returns: true if running Linux kernel is atleast at version
+ * Returns: true if running Linux kernel is at least at version
  * specified by (@major, @minor, @revision), else false.
  **/
 static bool
