@@ -256,6 +256,10 @@ show_confstrs_generic (void)
 	show_confstr (_CS_PATH);
 #endif
 
+#if defined (_CS_POSIX_V5_WIDTH_RESTRICTED_ENVS)
+	show_confstr (_CS_POSIX_V5_WIDTH_RESTRICTED_ENVS);
+#endif
+
 #if defined (_CS_POSIX_V6_ILP32_OFF32)
 	show_confstr (_CS_POSIX_V6_ILP32_OFF32);
 #endif
@@ -324,6 +328,10 @@ show_confstrs_generic (void)
 	show_confstr (_CS_POSIX_V6_LPBIG_OFFBIG_LINTFLAGS);
 #endif
 
+#if defined (_CS_POSIX_V6_WIDTH_RESTRICTED_ENVS)
+	show_confstr (_CS_POSIX_V6_WIDTH_RESTRICTED_ENVS);
+#endif
+
 #if defined (_CS_POSIX_V7_ILP32_OFF32_CFLAGS)
 	show_confstr (_CS_POSIX_V7_ILP32_OFF32_CFLAGS);
 #endif
@@ -388,6 +396,10 @@ show_confstrs_generic (void)
 	show_confstr (_CS_POSIX_V7_LPBIG_OFFBIG_LINTFLAGS);
 #endif
 
+#if defined (_CS_POSIX_V7_WIDTH_RESTRICTED_ENVS)
+	show_confstr (_CS_POSIX_V7_WIDTH_RESTRICTED_ENVS);
+#endif
+
 #if defined (_CS_V5_WIDTH_RESTRICTED_ENVS)
 	show_confstr (_CS_V5_WIDTH_RESTRICTED_ENVS);
 #endif
@@ -400,6 +412,10 @@ show_confstrs_generic (void)
 	_show_confstr (_CS_V5_WIDTH_RESTRICTED_ENVS, "XBS5_WIDTH_RESTRICTED_ENVS");
 #endif
 
+#if defined (_CS_V6_ENV)
+	show_confstr (_CS_V6_ENV);
+#endif
+
 #if defined (_CS_V6_WIDTH_RESTRICTED_ENVS)
 	show_confstr (_CS_V6_WIDTH_RESTRICTED_ENVS);
 #endif
@@ -408,6 +424,10 @@ show_confstrs_generic (void)
 	_show_confstr (_CS_V6_WIDTH_RESTRICTED_ENVS, "POSIX_V6_WIDTH_RESTRICTED_ENVS,_POSIX_V6_WIDTH_RESTRICTED_ENVS");
 #endif
 
+#if defined (_CS_V7_ENV)
+	show_confstr (_CS_V7_ENV);
+#endif
+
 #if defined (_CS_V7_WIDTH_RESTRICTED_ENVS)
 	show_confstr (_CS_V7_WIDTH_RESTRICTED_ENVS);
 #endif
@@ -638,6 +658,10 @@ show_pathconfs (ShowMountType what,
 		header ("pathconf");
 	}
 
+#if defined (_PC_2_SYMLINKS)
+	show_pathconf (what, dir, _PC_2_SYMLINKS);
+#endif
+
 #if defined (_PC_ALLOC_SIZE_MIN)
 	show_pathconf (what, dir, _PC_ALLOC_SIZE_MIN);
 #endif
@@ -710,10 +734,6 @@ show_pathconfs (ShowMountType what,
 	show_pathconf (what, dir, _PC_SYMLINK_MAX);
 #endif
 
-#if defined (_PC_2_SYMLINKS)
-	show_pathconf (what, dir, _PC_2_SYMLINKS);
-#endif
-
 #if defined (_PC_SYNC_IO)
 	show_pathconf (what, dir, _PC_SYNC_IO);
 #endif
@@ -924,10 +944,10 @@ show_mounts_generic_bsd (ShowMountType what,
  *
  * @path: path to convert to canonical form,
  * @canonical [out]: canonical version of @path,
- * @len: Size of @canonical (should be atleast PATH_MAX).
+ * @len: Size of @canonical (should be at least PATH_MAX).
  *
  * FIXME: this should fully resolve not just sym links but replace all
- * occurences of '../' by the appropriate direcotry!
+ * occurrences of '../' by the appropriate directory!
  **/
 int
 get_canonical_generic_linux (const char *path, char *canonical, size_t len)
