@@ -4,25 +4,11 @@
  *
  * Date: 24 October 2012.
  *
- * Author: James Hunt <jamesodhunt@gmail.com>.
+ * Author: James O. D. Hunt <jamesodhunt@gmail.com>.
  *
- * Licence: GPLv3. See below...
- *--------------------------------------------------------------------
+ * Copyright © 2012-2021 James O. D. Hunt <jamesodhunt@gmail.com>.
  *
- * Copyright © 2012-2016 James Hunt <jamesodhunt@gmail.com>.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *--------------------------------------------------------------------
  */
 
@@ -137,6 +123,10 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_2_PBS_ACCOUNTING),
 #endif
 
+#if defined (_SC_2_PBS_CHECKPOINT)
+	mk_sysconf_map_entry (_SC_2_PBS_CHECKPOINT),
+#endif
+
 #if defined (_SC_2_PBS_LOCATE)
 	mk_sysconf_map_entry (_SC_2_PBS_LOCATE),
 #endif
@@ -501,14 +491,14 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_OPEN_MAX),
 #endif
 
-#if defined (_SC_PAGESIZE)
-	mk_sysconf_map_entry (_SC_PAGESIZE),
-#endif
-
 #if defined (_SC_PAGE_SIZE)
 	mk_sysconf_map_entry (_SC_PAGE_SIZE),
 #endif
 
+#if defined (_SC_PAGESIZE)
+	mk_sysconf_map_entry (_SC_PAGESIZE),
+#endif
+
 #if defined (_SC_PASS_MAX)
 	mk_sysconf_map_entry (_SC_PASS_MAX),
 #endif
@@ -565,146 +555,10 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_POLL),
 #endif
 
-#if defined (_SC_SINGLE_PROCESS)
-	mk_sysconf_map_entry (_SC_SINGLE_PROCESS),
-#endif
-
-#if defined (_SC_SYSTEM_DATABASE)
-	mk_sysconf_map_entry (_SC_SYSTEM_DATABASE),
-#endif
-
-#if defined (_SC_SYSTEM_DATABASE_R)
-	mk_sysconf_map_entry (_SC_SYSTEM_DATABASE_R),
-#endif
-
-#if defined (_SC_THREAD_KEYS_MAX)
-	mk_sysconf_map_entry (_SC_THREAD_KEYS_MAX),
-#endif
-
-#if defined (_SC_THREAD_DESTRUCTOR_ITERATIONS)
-	mk_sysconf_map_entry (_SC_THREAD_DESTRUCTOR_ITERATIONS),
-#endif
-
-#if defined (_SC_THREAD_THREADS_MAX)
-	mk_sysconf_map_entry (_SC_THREAD_THREADS_MAX),
-#endif
-
-#if defined (_SC_STREAM_MAX)
-	mk_sysconf_map_entry (_SC_STREAM_MAX),
-#endif
-
-#if defined (_SC_SYMLOOP_MAX)
-	mk_sysconf_map_entry (_SC_SYMLOOP_MAX),
-#endif
-
-#if defined (_SC_TTY_NAME_MAX)
-	mk_sysconf_map_entry (_SC_TTY_NAME_MAX),
-#endif
-
-#if defined (_SC_TZNAME_MAX)
-	mk_sysconf_map_entry (_SC_TZNAME_MAX),
-#endif
-
-#if defined (_SC_TYPED_MEMORY_OBJECTS)
-	mk_sysconf_map_entry (_SC_TYPED_MEMORY_OBJECTS),
-#endif
-
-#if defined (_SC_USER_GROUPS)
-	mk_sysconf_map_entry (_SC_USER_GROUPS),
-#endif
-
-#if defined (_SC_USER_GROUPS_R)
-	mk_sysconf_map_entry (_SC_USER_GROUPS_R),
-#endif
-
-#if defined (_SC_VERSION)
-	mk_sysconf_map_entry (_SC_VERSION),
-#endif
-
 #if defined (_SC_POSIX2_C_DEV)
 	mk_sysconf_map_entry (_SC_POSIX2_C_DEV),
 #endif
 
-#if defined (_SC_SIGQUEUE_MAX)
-	mk_sysconf_map_entry (_SC_SIGQUEUE_MAX),
-#endif
-
-#if defined (_SC_T_IOV_MAX)
-	mk_sysconf_map_entry (_SC_T_IOV_MAX),
-#endif
-
-#if defined (_SC_THREAD_STACK_MIN)
-	mk_sysconf_map_entry (_SC_THREAD_STACK_MIN),
-#endif
-
-#if defined (_SC_SSIZE_MAX)
-	mk_sysconf_map_entry (_SC_SSIZE_MAX),
-#endif
-
-#if defined (_SC_TIMER_MAX)
-	mk_sysconf_map_entry (_SC_TIMER_MAX),
-#endif
-
-#if defined (_SC_UCHAR_MAX)
-	mk_sysconf_map_entry (_SC_UCHAR_MAX),
-#endif
-
-#if defined (_SC_UINT_MAX)
-	mk_sysconf_map_entry (_SC_UINT_MAX),
-#endif
-
-#if defined (_SC_UIO_MAXIOV)
-	mk_sysconf_map_entry (_SC_UIO_MAXIOV),
-#endif
-
-#if defined (_SC_ULONG_MAX)
-	mk_sysconf_map_entry (_SC_ULONG_MAX),
-#endif
-
-#if defined (_SC_USHRT_MAX)
-	mk_sysconf_map_entry (_SC_USHRT_MAX),
-#endif
-
-#if defined (_SC_V6_LPBIG_OFFBIG)
-	mk_sysconf_map_entry (_SC_V6_LPBIG_OFFBIG),
-#endif
-
-#if defined (_SC_WORD_BIT)
-	mk_sysconf_map_entry (_SC_WORD_BIT),
-#endif
-
-#if defined (_SC_EXPR_NEST_MAX)
-	mk_sysconf_map_entry (_SC_EXPR_NEST_MAX),
-#endif
-
-#if defined (_SC_V6_ILP32_OFF32)
-	mk_sysconf_map_entry (_SC_V6_ILP32_OFF32),
-#endif
-
-#if defined (_SC_V6_ILP32_OFFBIG)
-	mk_sysconf_map_entry (_SC_V6_ILP32_OFFBIG),
-#endif
-
-#if defined (_SC_V6_LP64_OFF64)
-	mk_sysconf_map_entry (_SC_V6_LP64_OFF64),
-#endif
-
-#if defined (_SC_V7_ILP32_OFF32)
-	mk_sysconf_map_entry (_SC_V7_ILP32_OFF32),
-#endif
-
-#if defined (_SC_V7_ILP32_OFFBIG)
-	mk_sysconf_map_entry (_SC_V7_ILP32_OFFBIG),
-#endif
-
-#if defined (_SC_V7_LPBIG_OFFBIG)
-	mk_sysconf_map_entry (_SC_V7_LPBIG_OFFBIG),
-#endif
-
-#if defined (_SC_V7_LP64_OFF64)
-	mk_sysconf_map_entry (_SC_V7_LP64_OFF64),
-#endif
-
 #if defined (_SC_PRIORITIZED_IO)
 	mk_sysconf_map_entry (_SC_PRIORITIZED_IO),
 #endif
@@ -789,6 +643,14 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_SIGNALS),
 #endif
 
+#if defined (_SC_SIGQUEUE_MAX)
+	mk_sysconf_map_entry (_SC_SIGQUEUE_MAX),
+#endif
+
+#if defined (_SC_SINGLE_PROCESS)
+	mk_sysconf_map_entry (_SC_SINGLE_PROCESS),
+#endif
+
 #if defined (_SC_SPAWN)
 	mk_sysconf_map_entry (_SC_SPAWN),
 #endif
@@ -801,10 +663,38 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_SPORADIC_SERVER),
 #endif
 
+#if defined (_SC_SSIZE_MAX)
+	mk_sysconf_map_entry (_SC_SSIZE_MAX),
+#endif
+
+#if defined (_SC_SS_REPL_MAX)
+	mk_sysconf_map_entry (_SC_SS_REPL_MAX),
+#endif
+
+#if defined (_SC_STREAM_MAX)
+	mk_sysconf_map_entry (_SC_STREAM_MAX),
+#endif
+
+#if defined (_SC_STREAMS)
+	mk_sysconf_map_entry (_SC_STREAMS),
+#endif
+
+#if defined (_SC_SYMLOOP_MAX)
+	mk_sysconf_map_entry (_SC_SYMLOOP_MAX),
+#endif
+
 #if defined (_SC_SYNCHRONIZED_IO)
 	mk_sysconf_map_entry (_SC_SYNCHRONIZED_IO),
 #endif
 
+#if defined (_SC_SYSTEM_DATABASE)
+	mk_sysconf_map_entry (_SC_SYSTEM_DATABASE),
+#endif
+
+#if defined (_SC_SYSTEM_DATABASE_R)
+	mk_sysconf_map_entry (_SC_SYSTEM_DATABASE_R),
+#endif
+
 #if defined (_SC_THREAD_ATTR_STACKADDR)
 	mk_sysconf_map_entry (_SC_THREAD_ATTR_STACKADDR),
 #endif
@@ -817,6 +707,14 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_THREAD_CPUTIME),
 #endif
 
+#if defined (_SC_THREAD_DESTRUCTOR_ITERATIONS)
+	mk_sysconf_map_entry (_SC_THREAD_DESTRUCTOR_ITERATIONS),
+#endif
+
+#if defined (_SC_THREAD_KEYS_MAX)
+	mk_sysconf_map_entry (_SC_THREAD_KEYS_MAX),
+#endif
+
 #if defined (_SC_THREAD_PRIO_INHERIT)
 	mk_sysconf_map_entry (_SC_THREAD_PRIO_INHERIT),
 #endif
@@ -841,6 +739,10 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_THREAD_ROBUST_PRIO_PROTECT),
 #endif
 
+#if defined (_SC_THREADS)
+	mk_sysconf_map_entry (_SC_THREADS),
+#endif
+
 #if defined (_SC_THREAD_SAFE_FUNCTIONS)
 	mk_sysconf_map_entry (_SC_THREAD_SAFE_FUNCTIONS),
 #endif
@@ -849,18 +751,30 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_THREAD_SPORADIC_SERVER),
 #endif
 
-#if defined (_SC_THREADS)
-	mk_sysconf_map_entry (_SC_THREADS),
+#if defined (_SC_THREAD_STACK_MIN)
+	mk_sysconf_map_entry (_SC_THREAD_STACK_MIN),
+#endif
+
+#if defined (_SC_THREAD_THREADS_MAX)
+	mk_sysconf_map_entry (_SC_THREAD_THREADS_MAX),
 #endif
 
 #if defined (_SC_TIMEOUTS)
 	mk_sysconf_map_entry (_SC_TIMEOUTS),
 #endif
 
+#if defined (_SC_TIMER_MAX)
+	mk_sysconf_map_entry (_SC_TIMER_MAX),
+#endif
+
 #if defined (_SC_TIMERS)
 	mk_sysconf_map_entry (_SC_TIMERS),
 #endif
 
+#if defined (_SC_T_IOV_MAX)
+	mk_sysconf_map_entry (_SC_T_IOV_MAX),
+#endif
+
 #if defined (_SC_TRACE)
 	mk_sysconf_map_entry (_SC_TRACE),
 #endif
@@ -869,6 +783,10 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_TRACE_EVENT_FILTER),
 #endif
 
+#if defined (_SC_TRACE_EVENT_NAME_MAX)
+	mk_sysconf_map_entry (_SC_TRACE_EVENT_NAME_MAX),
+#endif
+
 #if defined (_SC_TRACE_INHERIT)
 	mk_sysconf_map_entry (_SC_TRACE_INHERIT),
 #endif
@@ -877,8 +795,96 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_TRACE_LOG),
 #endif
 
-#if defined (_SC_TYPED_MEMORY_OBJECT)
-	mk_sysconf_map_entry (_SC_TYPED_MEMORY_OBJECT),
+#if defined (_SC_TRACE_NAME_MAX)
+	mk_sysconf_map_entry (_SC_TRACE_NAME_MAX),
+#endif
+
+#if defined (_SC_TRACE_SYS_MAX)
+	mk_sysconf_map_entry (_SC_TRACE_SYS_MAX),
+#endif
+
+#if defined (_SC_TRACE_USER_EVENT_MAX)
+	mk_sysconf_map_entry (_SC_TRACE_USER_EVENT_MAX),
+#endif
+
+#if defined (_SC_TTY_NAME_MAX)
+	mk_sysconf_map_entry (_SC_TTY_NAME_MAX),
+#endif
+
+#if defined (_SC_TYPED_MEMORY_OBJECTS)
+	mk_sysconf_map_entry (_SC_TYPED_MEMORY_OBJECTS),
+#endif
+
+#if defined (_SC_TZNAME_MAX)
+	mk_sysconf_map_entry (_SC_TZNAME_MAX),
+#endif
+
+#if defined (_SC_UCHAR_MAX)
+	mk_sysconf_map_entry (_SC_UCHAR_MAX),
+#endif
+
+#if defined (_SC_UINT_MAX)
+	mk_sysconf_map_entry (_SC_UINT_MAX),
+#endif
+
+#if defined (_SC_UIO_MAXIOV)
+	mk_sysconf_map_entry (_SC_UIO_MAXIOV),
+#endif
+
+#if defined (_SC_ULONG_MAX)
+	mk_sysconf_map_entry (_SC_ULONG_MAX),
+#endif
+
+#if defined (_SC_USER_GROUPS)
+	mk_sysconf_map_entry (_SC_USER_GROUPS),
+#endif
+
+#if defined (_SC_USER_GROUPS_R)
+	mk_sysconf_map_entry (_SC_USER_GROUPS_R),
+#endif
+
+#if defined (_SC_USHRT_MAX)
+	mk_sysconf_map_entry (_SC_USHRT_MAX),
+#endif
+
+#if defined (_SC_V6_ILP32_OFF32)
+	mk_sysconf_map_entry (_SC_V6_ILP32_OFF32),
+#endif
+
+#if defined (_SC_V6_ILP32_OFFBIG)
+	mk_sysconf_map_entry (_SC_V6_ILP32_OFFBIG),
+#endif
+
+#if defined (_SC_V6_LP64_OFF64)
+	mk_sysconf_map_entry (_SC_V6_LP64_OFF64),
+#endif
+
+#if defined (_SC_V6_LPBIG_OFFBIG)
+	mk_sysconf_map_entry (_SC_V6_LPBIG_OFFBIG),
+#endif
+
+#if defined (_SC_V7_ILP32_OFF32)
+	mk_sysconf_map_entry (_SC_V7_ILP32_OFF32),
+#endif
+
+#if defined (_SC_V7_ILP32_OFFBIG)
+	mk_sysconf_map_entry (_SC_V7_ILP32_OFFBIG),
+#endif
+
+#if defined (_SC_V7_LP64_OFF64)
+	mk_sysconf_map_entry (_SC_V7_LP64_OFF64),
+#endif
+
+#if defined (_SC_V7_LPBIG_OFFBIG)
+	mk_sysconf_map_entry (_SC_V7_LPBIG_OFFBIG),
+#endif
+
+#if defined (_SC_VERSION)
+	mk_sysconf_map_entry (_SC_VERSION),
+#endif
+
+#if defined (_SC_WORD_BIT)
+	mk_sysconf_map_entry (_SC_WORD_BIT),
 #endif
 
 #if defined (_SC_XBS5_ILP32_OFF32)
@@ -921,10 +927,22 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_XOPEN_SHM),
 #endif
 
+#if defined (_SC_XOPEN_STREAMS)
+	mk_sysconf_map_entry (_SC_XOPEN_STREAMS),
+#endif
+
 #if defined (_SC_XOPEN_UNIX)
 	mk_sysconf_map_entry (_SC_XOPEN_UNIX),
 #endif
 
+#if defined (_SC_XOPEN_VERSION)
+	mk_sysconf_map_entry (_SC_XOPEN_VERSION),
+#endif
+
+#if defined (_SC_XOPEN_XCU_VERSION)
+	mk_sysconf_map_entry (_SC_XOPEN_XCU_VERSION),
+#endif
+
 #if defined (_SC_XOPEN_XPG2)
 	mk_sysconf_map_entry (_SC_XOPEN_XPG2),
 #endif
@@ -937,14 +955,6 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_XOPEN_XPG4),
 #endif
 
-#if defined (_SC_XOPEN_VERSION)
-	mk_sysconf_map_entry (_SC_XOPEN_VERSION),
-#endif
-
-#if defined (_SC_XOPEN_XCU_VERSION)
-	mk_sysconf_map_entry (_SC_XOPEN_XCU_VERSION),
-#endif
-
 	{ NULL , 0 }
 };
 
@@ -1112,7 +1122,7 @@ usage (void)
  * In additional to the classical semantics, by careful use of clone(2),
  * it is possible for a child to inherit its parents dispositions
  * (using clone's CLONE_SIGHAND+CLONE_VM flags). This is possible since
- * the child then shares the parents signal handlers, which inherantly
+ * the child then shares the parents signal handlers, which inherently 
  * therefore provide access to the dispositions).
  **/
 void
@@ -1145,7 +1155,7 @@ show_signals (void)
 		; /* NOP */
 	}
 
-	/* Note that we don't interate the signal map directly in case the
+	/* Note that we don't iterate the signal map directly in case the
 	 * entries are out of order. Instead, present the signals in numeric
 	 * order.
 	 */
@@ -1488,13 +1498,13 @@ show_env (void)
 
 	copy = calloc (1+max, sizeof (char *));
 	if (! copy)
-		die ("failed to alloate storage");
+		die ("failed to allocate storage");
 
 	/* Copy the environ array since modification is not allowed */
 	for (i=0; i < max; i++) {
 		copy[i] = calloc (1, 1+strlen (env[i]));
 		if (! copy[i])
-			die ("failed to alloate storage");
+			die ("failed to allocate storage");
 		strcpy (copy[i], env[i]);
 	}
 
@@ -3574,7 +3584,7 @@ check_envvars (void)
 			die ("invalid command");
 		}
 
-		/* there must be atleast an no-arg command to run */
+		/* there must be at least an no-arg command to run */
 		count = 1;
 
 		/* establish number of fields required for program arguments */
@@ -4182,7 +4192,7 @@ main (int    argc,
 	output_init ();
 
 	if (reexec && ! exec_args && optind >= argc)
-		die ("must specify atleast one argument with '--exec'");
+		die ("must specify at least one argument with '--exec'");
 
 	/* Prepare for re-exec */
 	if (reexec) {
@@ -4389,7 +4399,7 @@ format_perms (mode_t mode)
  */
 #ifdef PROCENV_PLATFORM_ANDROID
 
-// FIXME: split out to platfom
+// FIXME: split out to platform
 void
 show_network (void)
 {
